@@ -12,4 +12,4 @@ from micawber.providers import ProviderRegistry
 from micawber.providers import bootstrap_basic
 from micawber.providers import bootstrap_embedly
 from micawber.providers import bootstrap_noembed
-from micawber.providers import bootstrap_oembedio
+from micawber.providers import bootstrap_oembed
